@@ -376,6 +376,20 @@ class Rock:
         # doing this makes the g_sys independent from the absolute input used (depends on personal format choice)
         self.g_system_per_mol_of_input = self.g_system / sum_mol_input_elements
 
+    def add_bulk_density(self, block_volume: list):
+        """Reads the bulk density of solid phases form te respective theriak output block.
+        Attention: Depending on the activated melt model, melts can be included in solid phases, therefore affecting also bulk density.
+
+        Args:
+            block_volume (list): block_volume from blocks (splitted theriak output --> generated by TherCaller.call_theriak())
+        """
+        bulk_properties_line = [line for line in block_volume if line.startswith("  total of solids")][0]
+        bulk_density = bulk_properties_line.split()[-1]
+        # transform str --> float
+        bulk_density = float(bulk_density)
+
+        self.bulk_density = bulk_density
+
     def add_minerals(self, block_volume: list, block_composition: list, block_elements: list, output_line_overflow: bool):
         temp_name_list = Rock.get_mineral_list(block_volume=block_volume)
 
